package javax.xml.crypto.dsig.dom;

import java.security.Key;
import javax.xml.crypto.KeySelector;
import org.w3c.dom.Node;
import javax.xml.crypto.dsig.XMLValidateContext;
import javax.xml.crypto.dom.DOMCryptoContext;

public class DOMValidateContext extends DOMCryptoContext implements XMLValidateContext
{
    private Node node;
    
    public DOMValidateContext(KeySelector keySelector, Node node) {
        if (keySelector == null) {
            throw new NullPointerException("key selector is null");
        }
        this.init(node, keySelector);
        return;
    }
    
    public DOMValidateContext(Key key, Node node) {
        if (key == null) {
            throw new NullPointerException("validatingKey is null");
        }
        this.init(node, KeySelector.singletonKeySelector(key));
        return;
    }
    
    private void init(Node node, KeySelector keySelector) {
        if (node == null) {
            throw new NullPointerException("node is null");
        }
        this.node = node;
        super.setKeySelector(keySelector);
        if (System.getSecurityManager() != null) {
            super.setProperty("org.jcp.xml.dsig.secureValidation", Boolean.TRUE);
        }
        return;
    }
    
    public void setNode(Node node) {
        if (node == null) {
            throw new NullPointerException();
        }
        this.node = node;
        return;
    }
    
    public Node getNode() {
        return this.node;
    }
}
